@@ -5,9 +5,9 @@
 import pandas as pd
 from sklearn.feature_extraction.text import TfidfVectorizer
 from collections import Counter
-import json
 import string, nltk
 from nltk.corpus import stopwords
+import urllib.request, json
 nltk.download('wordnet')
 nltk.download('punkt')
 nltk.download('stopwords')
@@ -51,8 +51,8 @@ def get_emotions(self):
 class EmoTFIDF:
     """Lexicon source is (C) 2016 National Research Council Canada (NRC) and library is for research purposes only.  Source: http://sentiment.nrc.ca/lexicons-for-research/"""
 
-    with open('https://raw.githubusercontent.com/mmsa/EmoTFIDF/main/emotions_lex.json') as jsonfile:
-        lexicon = json.load(jsonfile)
+    with urllib.request.urlopen("https://raw.githubusercontent.com/mmsa/EmoTFIDF/main/emotions_lex.json") as url:
+        data = json.loads(url.read().decode())
 
     def set_text(self, text):
         self.text = process_message(text)
